"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  httpHandler: true,
  websocketHandler: true,
  eventHandler: true
};
exports.eventHandler = exports.websocketHandler = exports.httpHandler = void 0;

var _awsLambdaGraphql = require("aws-lambda-graphql");

var _pkgDir = _interopRequireDefault(require("pkg-dir"));

var _path = _interopRequireDefault(require("path"));

var _PubSub = require("./PubSub");

Object.keys(_PubSub).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _PubSub[key];
    }
  });
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const GRAPH_QL_SCHEMA_PATH = process.env.GRAPH_QL_SCHEMA_PATH || './schema';
const GRAPH_QL_CONNECTIONS_TABLE = process.env.GRAPH_QL_CONNECTIONS_TABLE || 'GraphQlConnections';
const GRAPH_QL_SUBSCRIPTIONS_TABLE = process.env.GRAPH_QL_SUBSCRIPTIONS_TABLE || 'GraphQlSubscriptions';
const connectionManager = new _awsLambdaGraphql.DynamoDBConnectionManager({
  connectionsTable: GRAPH_QL_CONNECTIONS_TABLE
});
const subscriptionManager = new _awsLambdaGraphql.DynamoDBSubscriptionManager({
  subscriptionsTableName: GRAPH_QL_SUBSCRIPTIONS_TABLE
});

const rootDir = _pkgDir.default.sync();

const relRootPath = _path.default.relative(__dirname, rootDir);

const relSchemaPath = _path.default.join(relRootPath, GRAPH_QL_SCHEMA_PATH); // $FlowIgnoreLine


const schema = require(relSchemaPath); // eslint-disable-line


const wrappedHttpHander = (0, _awsLambdaGraphql.createHttpHandler)({
  connectionManager,
  schema
}); // eslint-disable-next-line flowtype/no-weak-types

const httpHandler = async (event, context, callback) => {
  // Serverless provides "content-type", but library expects "Content-Type" https://github.com/michalkvasnicak/aws-lambda-graphql/blob/master/packages/aws-lambda-graphql/src/createHttpHandler.ts#L25
  // eslint-disable-next-line no-param-reassign
  event.headers['Content-Type'] = event.headers['Content-Type'] || event.headers['content-type'];
  const result = await wrappedHttpHander(event, context, callback);
  return result;
};

exports.httpHandler = httpHandler;
const websocketHandler = (0, _awsLambdaGraphql.createWsHandler)({
  connectionManager,
  schema,
  subscriptionManager
});
exports.websocketHandler = websocketHandler;
const eventHandler = (0, _awsLambdaGraphql.createDynamoDBEventProcessor)({
  connectionManager,
  schema,
  subscriptionManager
});
exports.eventHandler = eventHandler;